pub struct RateConfig {
pub phy_mode: PhyMode,
pub rate: WifiPhyRate,
pub ersu: bool,
pub dcm: bool,
}Available on crate features
esp-now and unstable only.Expand description
Rate Config
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Fields
phy_mode: PhyModePhy mode
rate: WifiPhyRateThe rate
ersu: boolUsing ERSU to send frame, ERSU is a transmission mode related to 802.11 ax. ERSU is always used in long distance transmission, and its frame has lower rate compared with SU mode
dcm: boolUsing dcm rate to send frame